import datetime
import fileinput
import os
import re

# Generate version string
new_version = datetime.datetime.now().strftime("%Y.%-m.%-d")
year = datetime.datetime.now().year

# Update __version__ variable in pefile.py
pefile_path = "./pefile.py"
version_pattern = r"__version__\s*=\s*['\"]\d{4}\.\d{1,2}\.\d{1,2}['\"]"
new_version_line = f"__version__ = \"{new_version}\""

with fileinput.FileInput(pefile_path, inplace=True) as file:
    for line in file:
        new_line = re.sub(version_pattern, new_version_line, line)
        print(new_line, end="")

# Update version-like strings in setup.py and CITATION.cff
files_to_update = [
    "./setup.py",
    "./CITATION.cff",
]

for file_path in files_to_update:
    with fileinput.FileInput(file_path, inplace=True) as file:
        for line in file:
            new_line = re.sub(r"\d{4}\.\d{1,2}\.\d{1,2}", new_version, line)
            print(new_line, end="")

# Update last year occurrences in pefile.py, CITATION.cff, and LICENSE
files_to_update = [
    pefile_path,
    "./CITATION.cff",
    "./LICENSE",
]

for file_path in files_to_update:
    with fileinput.FileInput(file_path, inplace=True) as file:
        for line in file:
            new_line = line.replace(str(year - 1), str(year)).replace(
                str(year - 2), str(year)
            )
            print(new_line, end="")

# Update version-like strings in setup.py, CITATION.cff, and LICENSE
files_to_update = ["./CITATION.cff"]

for file_path in files_to_update:
    with fileinput.FileInput(file_path, inplace=True) as file:
        for line in file:
            new_line = re.sub(
                r"\d{4}-\d{2}-\d{2}", datetime.datetime.now().strftime("%Y-%m-%d"), line
            )  # Update the regex pattern
            print(new_line, end="")

# Log the changes
log_message = (
    f"Version updated to {new_version}. Last year occurrences updated to {year}."
)
print(log_message)



# This tool will go through all the dmp files and apply some formatting fixes.

import os
import re

BASE_PATH = '/Users/erocarrera/Devel/pefile/tests/test_files'

parse_date_line = re.compile('.*TimeDateStamp:\s+0x[a-fA-F0-9]+\s+\[')

def process_file(filepath):
    print(f'Processing file: {filepath}')
    lines = []
    with open(filepath) as f:
        data = f.read()
        # with open(filepath+'.bak_20190929', 'w') as bak:
        #     bak.write(data)
        for line in data.split('\n'):
            if line == '----------DOS_HEADER----------':
                if lines and lines[0] == '----------Parsing Warnings----------':
                    print('Warnings found')
                    lines = (
                        ['----------Parsing Warnings----------', '',] +
                        [l for l in lines[1:-1] if l] +
                        ['',])
            if line.strip() == 'DllCharacteristics:':
                continue
            if parse_date_line.match(line):
                lines.append(re.sub(
                    r'(TimeDateStamp:\s+0x[a-fA-F0-9]+)\s+\[', r'\1 [', line))
            else:
                lines.append(line.rstrip())
    with open(filepath, 'w') as f:
        f.write('\n'.join(lines))
    # print('\n'.join(lines))
    # os.sys.exit()

for (dirpath, dirnames, filenames) in os.walk(BASE_PATH):
    dmp_files = [fname for fname in filenames if fname.endswith('.dmp')]
    print(f'Processing directory: {dirpath}, which has {len(dmp_files)} files')
    # print(f'Files: {dmp_files}')
    for dmp_file in dmp_files:
        process_file(os.path.join(dirpath, dmp_file))



import os
import pefile

def process_file(file_path):
    try:
        pe = pefile.PE(file_path)
        memory_mapped_image = pe.get_memory_mapped_image()
        print(f"{file_path}: {len(memory_mapped_image)} bytes")
    except pefile.PEFormatError:
        pass

def find_files(directory):
    results = []
    for root, dirs, files in os.walk(directory):
        for file in files:
            if not file.endswith(".dmp"):
                file_path = os.path.join(root, file)
                result = process_file(file_path)
                if result:
                    results.append(result)
    return results

if __name__ == "__main__":
    directory = "./tests/test_files"
    results = find_files(directory)



#!/usr/bin/python

import ast
import os
import re
import sys
from unittest import TestLoader, TextTestRunner

from setuptools import Command, setup


os.environ["COPY_EXTENDED_ATTRIBUTES_DISABLE"] = "true"
os.environ["COPYFILE_DISABLE"] = "true"


def _read_doc():
    """
    Parse docstring from file 'pefile.py' and avoid importing
    this module directly.
    """
    with open("pefile.py", "r", encoding="utf-8") as f:
        tree = ast.parse(f.read())
    return ast.get_docstring(tree)


def _read_attr(attr_name):
    """
    Parse attribute from file 'pefile.py' and avoid importing
    this module directly.

    __version__, __author__, __contact__,
    """
    regex = attr_name + r"\s+=\s+['\"](.+)['\"]"
    with open("pefile.py", "r", encoding="utf-8") as f:
        match = re.search(regex, f.read())
    # Second item in the group is the value of attribute.
    return match.group(1)


class TestCommand(Command):
    """Run tests."""

    user_options = []

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        test_suite = TestLoader().discover("./tests", pattern="*_test.py")
        test_results = TextTestRunner(verbosity=2).run(test_suite)


setup(
    name="pefile",
    version=_read_attr("__version__"),
    description="Python PE parsing module",
    author=_read_attr("__author__"),
    author_email=_read_attr("__contact__"),
    url="https://github.com/erocarrera/pefile",
    download_url="https://github.com/erocarrera/pefile/releases/download/v2024.8.26/pefile-2024.8.26.tar.gz",
    keywords=["pe", "exe", "dll", "pefile", "pecoff"],
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Intended Audience :: Science/Research",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    long_description="\n".join(_read_doc().split("\n")),
    cmdclass={"test": TestCommand},
    py_modules=["pefile", "peutils"],
    python_requires=">=3.6.0",
    packages=["ordlookup"],
    install_requires=[],
    license="MIT",
)



import timeit
import pefile
import tracemalloc
import sys

def run_pefile(show_info=False):
    with open(sys.argv[1], 'rb') as f:
        data = f.read()
    pe = pefile.PE(data=data)
    l = len(pe.dump_info())
    if show_info:
        print(type(pe.__data__))
        print(l)

tracemalloc.start()  # Start tracing memory allocations
run_pefile(show_info=True)
snapshot = tracemalloc.take_snapshot()  # Take a snapshot of current memory allocations
top_stats = snapshot.statistics('lineno')  # Get statistics grouped by line number

for stat in top_stats[:10]:  # Print top 10 memory consuming lines
    print(stat)

print(timeit.timeit(run_pefile, number=4))
